==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/coredata/NSManagedObjectContextConcurrencyType.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coredata;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 5.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedUIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/ implements ValuedEnum {
    /*<values>*/
    /**
     * @since Available in iOS 3.0 and later.
     * @deprecated Deprecated in iOS 9.0.
     */
    @Deprecated
    Confinement(0L),
    PrivateQueue(1L),
    MainQueue(2L);
    /*</values>*/

    private final long n;

    private /*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/ valueOf(long n) {
        for (/*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/.class.getName());
    }
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/coredata/NSManagedObjectContextConcurrencyType.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.coredata;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corespotlight.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.uikit.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Marshaler(ValuedEnum.AsMachineSizedUIntMarshaler.class)/*</annotations>*/
public enum /*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/ implements ValuedEnum {
    /*<values>*/
    /**
     * @deprecated Deprecated in iOS 9.0. Use another NSManagedObjectContextConcurrencyType
     */
    @Deprecated
    Confinement(0L),
    PrivateQueue(1L),
    MainQueue(2L);
    /*</values>*/

    private final long n;

    private /*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/(long n) { this.n = n; }
    public long value() { return n; }
    public static /*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/ valueOf(long n) {
        for (/*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/ v : values()) {
            if (v.n == n) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + n + " found in " 
            + /*<name>*/NSManagedObjectContextConcurrencyType/*</name>*/.class.getName());
    }
}
